@@ -29,7 +29,7 @@ _bounds = {
         "start": [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12],
         "end": [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12],
     },
-    "month": {
+    "mon": {
         "start": [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12],
         "end": [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12],
     },
@@ -41,7 +41,16 @@ _fmt = {
     "fx": "%Y%m%d",
     "day": "%Y%m%d",
     "week": "%Y%m%d",
-    "month": "%Y%m",
+    "mon": "%Y%m",
     "sem": "%Y%m",
     "year": "%Y",
 }
+
+_split = {
+    "fx": False,
+    "day": "5AS",
+    "week": "10AS",
+    "mon": "10AS",
+    "sem": "10AS",
+    "year": "20AS",
+}
