@@ -1,6 +1,7 @@
 import re
 
-import cftime
+import cf_xarray  # noqa
+import cftime  # noqa
 import pyhomogenize as pyh
 import xarray as xr
 
@@ -10,7 +11,32 @@ from ._utils import check_existance, kwargs_to_self, object_attrs_to_self
 
 
 class Processing:
-    """Class for processing."""
+    """Class for processing ``index_calculator.preprocessing`` object.
+
+    Parameters
+    ----------
+    index: str
+        Climate indicator name to be calculated.
+    preproc_obj: index_calculator.preprocessing
+        ``index_calculator.preprocessing`` object
+
+    Example
+    -------
+    Calculate a climate indicator `TG` from netcdf file on disk::
+
+        from pyhomogenize import open_xrdataset
+        from index_calculator import preprocessing
+        from index_calculator import processing
+
+        netcdf_file = "tas_EUR-11_MPI-M-MPI-ESM-LR_historical_r3i1p1_"
+                      "GERICS-REMO2015_v1_day_20010101-20051231.nc"
+        ds = open_xrdataset(netcdf_file)
+
+        preproc = preprocessing(ds)
+        proc = processing(index="TG", preproc_obj=preproc)
+
+        proc_ds = proc.proc
+    """
 
     def __init__(
         self,
@@ -18,7 +44,6 @@ class Processing:
         preproc_obj=None,
         **kwargs,
     ):
-        """Write parameters to self."""
         if preproc_obj is None:
             raise ValueError(
                 "Please select an index_calculator.PreProcessing object."
@@ -28,7 +53,7 @@ class Processing:
         self.CIname = check_existance({"index": index}, self)
         kwargs_to_self(kwargs, self)
         self._get_idx_name_and_repl()
-        self.proc = self.processing()
+        self.proc = self._processing()
 
     def _get_numb_name_and_idx_object(self):
         alpha_name = "".join(filter(lambda x: x.isalpha(), self.CIname))
@@ -107,7 +132,7 @@ class Processing:
         params.update(self.replacement)
         return params
 
-    def processing(self):
+    def _processing(self):
         """Calculate climate index."""
         params = self._adjust_params_to_ci()
         array = self.compute(**params)
@@ -117,48 +142,26 @@ class Processing:
             end=self.preproc.time.values[-1],
             frequency=_tfreq[self.freq],
         )
-        array = array.assign_coords({"time": date_range})
         data_vars = {
             k: self.preproc.data_vars[k]
             for k in self.preproc.data_vars.keys()
             if k not in self.var_name
         }
         data_vars[self.CIname] = array
-        data_vars["time"] = array["time"]
-        del data_vars["time_bnds"]
+        if "time_bnds" in data_vars.keys():
+            del data_vars["time_bnds"]
+        if "time_bounds" in data_vars.keys():
+            del data_vars["time_bounds"]
         idx_ds = xr.Dataset(data_vars=data_vars, attrs=self.preproc.attrs)
-        new_time = cftime.date2num(
-            idx_ds.time,
-            self.ds.time.encoding["units"],
-            calendar=self.ds.time.encoding["calendar"],
-        )
-        idx_ds = idx_ds.assign_coords({"time": new_time})
-        encoding = {
-            "units": self.ds.time.encoding["units"],
-            "calendar": self.ds.time.encoding["calendar"],
-            "dtype": self.ds.time.encoding["dtype"],
-        }
-        self.encoding = {
-            "time": encoding,
-        }
         if len(idx_ds.time) > 1:
+            idx_ds = idx_ds.assign_coords(
+                {"time": date_range.to_datetimeindex},
+            )
             idx_ds = idx_ds.cf.add_bounds("time")
             idx_ds = idx_ds.reset_coords("time_bounds")
-            idx_ds["time_bounds"] = idx_ds.time_bounds.transpose()
-
-            new_time_bnds = cftime.num2date(
-                idx_ds.time_bounds,
-                self.ds.time.encoding["units"],
-                calendar=self.ds.time.encoding["calendar"],
-            )
-            idx_ds.time_bounds.values = new_time_bnds
-            idx_ds = idx_ds.rename({"time_bounds": "time_bnds"})
-            self.encoding["time_bnds"] = encoding
-
-        new_time = cftime.num2date(
-            idx_ds.time,
-            self.ds.time.encoding["units"],
-            calendar=self.ds.time.encoding["calendar"],
-        )
-        idx_ds = idx_ds.assign_coords({"time": new_time})
+        for data_var in idx_ds.data_vars:
+            data_var_repl = data_var.replace("bounds", "bnds")
+            idx_ds = idx_ds.rename({data_var: data_var_repl})
+        idx_ds = idx_ds.assign_coords({"time": date_range})
+        idx_ds.time.encoding = self.ds.time.encoding
         return idx_ds
