@@ -23,5 +23,4 @@ def read_from_json(jsfile):
 ijson = read_from_json("tables/indices.json")
 xjson = read_from_json("tables/xcalc.json")
 pjson = read_from_json("tables/projects.json")
-istjson = read_from_json("tables/institutions.json")
-inpjson = read_from_json("tables/input_vars.json")
+vjson = read_from_json("tables/input_vars.json")
